@@ -2,15 +2,24 @@ from nglui import EasyViewer, annotation
 import pandas as pd
 import numpy as np
 from .utils import bucket_of_values
-from .mappers import SelectionMapper, AnnotationMapperBase, PointMapper, LineMapper, SphereMapper, BoundingBoxMapper
+from .mappers import (
+    SelectionMapper,
+    AnnotationMapperBase,
+    PointMapper,
+    LineMapper,
+    SphereMapper,
+    BoundingBoxMapper,
+)
 
-DEFAULT_IMAGE_LAYER = 'img'
-DEFAULT_SEG_LAYER = 'seg'
-DEFAULT_ANNO_LAYER = 'anno'
+DEFAULT_IMAGE_LAYER = "img"
+DEFAULT_SEG_LAYER = "seg"
+DEFAULT_ANNO_LAYER = "anno"
 
-DEFAULT_SEGMENTATION_VIEW_KWS = {'alpha_selected': 0.3,
-                                 'alpha_3d': 1,
-                                 'alpha_unselected': 0}
+DEFAULT_SEGMENTATION_VIEW_KWS = {
+    "alpha_selected": 0.3,
+    "alpha_3d": 1,
+    "alpha_unselected": 0,
+}
 
 
 class LayerConfigBase(object):
@@ -30,63 +39,63 @@ class LayerConfigBase(object):
         If True, becomes a selected layer.
     """
 
-    def __init__(self,
-                 name,
-                 type,
-                 source,
-                 color,
-                 active,
-                 ):
-        self._config = dict(type=type,
-                            name=name,
-                            source=source,
-                            color=color,
-                            active=active,
-                            )
+    def __init__(
+        self,
+        name,
+        type,
+        source,
+        color,
+        active,
+    ):
+        self._config = dict(
+            type=type,
+            name=name,
+            source=source,
+            color=color,
+            active=active,
+        )
 
     @property
     def type(self):
-        return self._config.get('type', None)
+        return self._config.get("type", None)
 
     @property
     def name(self):
-        return self._config.get('name', None)
+        return self._config.get("name", None)
 
     @name.setter
     def name(self, n):
-        self._config['name'] = n
+        self._config["name"] = n
 
     @property
     def source(self):
-        return self._config.get('source', None)
+        return self._config.get("source", None)
 
     @source.setter
     def source(self, s):
-        self._config['source'] = s
+        self._config["source"] = s
 
     @property
     def color(self):
-        return self._config.get('color', None)
+        return self._config.get("color", None)
 
     @color.setter
     def color(self, c):
-        self._config['color'] = c
+        self._config["color"] = c
 
     @property
     def active(self):
-        return self._config.get('active', False)
+        return self._config.get("active", False)
 
     def _render_layer(self, viewer, data):
-        """ Applies rendering rules
-        """
+        """Applies rendering rules"""
         self._specific_rendering(viewer, data)
         if self.active:
             viewer.set_selected_layer(self.name)
         return viewer
 
     def _specific_rendering(self, viewer, data):
-        """ Subclasses implement specific rendering rules
-        """
+        """Subclasses implement specific rendering rules"""
         pass
 
 
@@ -111,18 +120,20 @@ class ImageLayerConfig(LayerConfigBase):
         If contrast_controls is True, sets the default white level. Default is 1.0.
     """
 
-    def __init__(self,
-                 source,
-                 name=None,
-                 active=False,
-                 contrast_controls=False,
-                 black=0.0,
-                 white=1.0,
-                 ):
+    def __init__(
+        self,
+        source,
+        name=None,
+        active=False,
+        contrast_controls=False,
+        black=0.0,
+        white=1.0,
+    ):
         if name is None:
             name = DEFAULT_IMAGE_LAYER
         super(ImageLayerConfig, self).__init__(
-            name=name, type='image', source=source, color=None, active=active)
+            name=name, type="image", source=source, color=None, active=active
+        )
         self._contrast_controls = contrast_controls
         self._black = black
         self._white = white
@@ -130,8 +141,7 @@ class ImageLayerConfig(LayerConfigBase):
     def _specific_rendering(self, viewer, data):
         viewer.add_image_layer(self.name, self.source)
         if self._contrast_controls:
-            viewer.add_contrast_shader(
-                self.name, black=self._black, white=self._white)
+            viewer.add_contrast_shader(self.name, black=self._black, white=self._white)
 
 
 class SegmentationLayerConfig(LayerConfigBase):
@@ -160,41 +170,52 @@ class SegmentationLayerConfig(LayerConfigBase):
         Opacity of meshes. Optional, default is 1.
     alpha_unselected: float, optional
         Opacity of unselected segments. Optional, default is 0.
+    split_point_map: mappers.SplitPointMap or None, optional
+        If not None, provides an object to map the dataframe input to multicut points. Default is None.
     view_kws : dict, optional.
         Keyword arguments for viewer.set_segmentation_view_options. Sets selected (and unselected) segmetation alpha values. Defaults to values in DEFAULT_SEGMENTATION_VIEW_KWS dict specified in this module.
-   """
+    """
 
-    def __init__(self,
-                 source,
-                 name=None,
-                 selected_ids_column=None,
-                 fixed_ids=None,
-                 fixed_id_colors=None,
-                 color_column=None,
-                 active=False,
-                 alpha_selected=0.3,
-                 alpha_3d=1,
-                 alpha_unselected=0,
-                 view_kws=None,
-                 ):
+    def __init__(
+        self,
+        source,
+        name=None,
+        selected_ids_column=None,
+        fixed_ids=None,
+        fixed_id_colors=None,
+        color_column=None,
+        active=False,
+        alpha_selected=0.3,
+        alpha_3d=1,
+        alpha_unselected=0,
+        split_point_map=None,
+        view_kws=None,
+    ):
         if name is None:
             name = DEFAULT_SEG_LAYER
 
         super(SegmentationLayerConfig, self).__init__(
-            name=name, type='segmentation', source=source, color=None, active=active)
+            name=name, type="segmentation", source=source, color=None, active=active
+        )
         if selected_ids_column is not None or fixed_ids is not None:
             self._selection_map = SelectionMapper(
                 data_columns=selected_ids_column,
                 fixed_ids=fixed_ids,
                 fixed_id_colors=fixed_id_colors,
-                color_column=color_column)
+                color_column=color_column,
+            )
         else:
             self._selection_map = None
 
+        self._split_point_map = split_point_map
+
         base_seg_kws = DEFAULT_SEGMENTATION_VIEW_KWS.copy()
         if view_kws is None:
-            view_kws = {'alpha_selected': alpha_selected,
-                        'alpha_3d': alpha_3d, 'alpha_unselected': alpha_unselected}
+            view_kws = {
+                "alpha_selected": alpha_selected,
+                "alpha_3d": alpha_3d,
+                "alpha_unselected": alpha_unselected,
+            }
         base_seg_kws.update(view_kws)
         self._view_kws = view_kws
 
@@ -202,20 +223,39 @@ class SegmentationLayerConfig(LayerConfigBase):
         if self._selection_map is not None:
             if isinstance(selected_ids_column, str):
                 selected_ids_column = [selected_ids_column]
-            data_columns = self._selection_map.data_columns.extend(
-                selected_ids_column)
+            data_columns = self._selection_map.data_columns.extend(selected_ids_column)
             fixed_ids = self._selection_map.fixed_ids.extend(fixed_ids)
 
         self._selection_map = SelectionMapper(
-            data_columns=data_columns,
-            fixed_ids=fixed_ids)
+            data_columns=data_columns, fixed_ids=fixed_ids
+        )
 
     def _specific_rendering(self, viewer, data):
         viewer.add_segmentation_layer(self.name, self.source)
+
         if self._selection_map is not None:
             selected_ids = self._selection_map.selected_ids(data)
             colors = self._selection_map.seg_colors(data)
             viewer.add_selected_objects(self.name, selected_ids, colors)
+
+        if self._split_point_map is not None:
+            (
+                seg_id,
+                points_red,
+                points_blue,
+                sv_red,
+                sv_blue,
+            ) = self._split_point_map._render_data(data)
+            viewer.set_multicut_points(
+                self.name,
+                seg_id,
+                points_red,
+                points_blue,
+                sv_red,
+                sv_blue,
+                self._split_point_map.focus,
+            )
+
         viewer.set_segmentation_view_options(self.name, **self._view_kws)
 
 
@@ -241,33 +281,34 @@ class AnnotationLayerConfig(LayerConfigBase):
         If True, makes the layer selected. Default is True (unlike for image/segmentation layers).
     """
 
-    def __init__(self,
-                 name=None,
-                 color=None,
-                 linked_segmentation_layer=None,
-                 mapping_rules=[],
-                 array_data=False,
-                 tags=None,
-                 active=True,
-                 filter_by_segmentation=False,
-                 brackets_show_segmentation=True,
-                 selection_shows_segmentation=True,
-                 ):
+    def __init__(
+        self,
+        name=None,
+        color=None,
+        linked_segmentation_layer=None,
+        mapping_rules=[],
+        array_data=False,
+        tags=None,
+        active=True,
+        filter_by_segmentation=False,
+        brackets_show_segmentation=True,
+        selection_shows_segmentation=True,
+    ):
         if name is None:
             name = DEFAULT_ANNO_LAYER
 
         super(AnnotationLayerConfig, self).__init__(
-            name=name, type='annotation', color=color, source=None, active=active)
-        self._config['linked_segmentation_layer'] = linked_segmentation_layer
-        self._config['filter_by_segmentation'] = filter_by_segmentation
-        self._config['selection_shows_segmentation'] = selection_shows_segmentation
-        self._config['brackets_show_segmentation'] = brackets_show_segmentation
+            name=name, type="annotation", color=color, source=None, active=active
+        )
+        self._config["linked_segmentation_layer"] = linked_segmentation_layer
+        self._config["filter_by_segmentation"] = filter_by_segmentation
+        self._config["selection_shows_segmentation"] = selection_shows_segmentation
+        self._config["brackets_show_segmentation"] = brackets_show_segmentation
         if issubclass(type(mapping_rules), AnnotationMapperBase):
             mapping_rules = [mapping_rules]
         if array_data is True:
             if len(mapping_rules) > 1:
-                raise ValueError(
-                    "Only one mapping rule can be set using array data")
+                raise ValueError("Only one mapping rule can be set using array data")
             for mr in mapping_rules:
                 mr.array_data = array_data
         self._array_data = array_data
@@ -276,28 +317,30 @@ class AnnotationLayerConfig(LayerConfigBase):
 
     @property
     def linked_segmentation_layer(self):
-        return self._config.get('linked_segmentation_layer', None)
+        return self._config.get("linked_segmentation_layer", None)
 
     @property
     def filter_by_segmentation(self):
-        return self._config.get('filter_by_segmentation', None)
+        return self._config.get("filter_by_segmentation", None)
 
     @property
     def selection_shows_segmentation(self):
-        return self._config.get('selection_shows_segmentation', None)
+        return self._config.get("selection_shows_segmentation", None)
 
     @property
     def brackets_show_segmentation(self):
-        return self._config.get('brackets_show_segmentation', None)
+        return self._config.get("brackets_show_segmentation", None)
 
     def _specific_rendering(self, viewer, data):
-        viewer.add_annotation_layer(self.name,
-                                    color=self.color,
-                                    linked_segmentation_layer=self.linked_segmentation_layer,
-                                    filter_by_segmentation=self.filter_by_segmentation,
-                                    selection_shows_segmentation=self.selection_shows_segmentation,
-                                    brackets_show_segmentation=self.brackets_show_segmentation,
-                                    tags=self._tags)
+        viewer.add_annotation_layer(
+            self.name,
+            color=self.color,
+            linked_segmentation_layer=self.linked_segmentation_layer,
+            filter_by_segmentation=self.filter_by_segmentation,
+            selection_shows_segmentation=self.selection_shows_segmentation,
+            brackets_show_segmentation=self.brackets_show_segmentation,
+            tags=self._tags,
+        )
         annos = []
         for rule in self._annotation_map_rules:
             rule.tag_map = self._tags
